[asterisk-scf-commits] asterisk-scf/release/cmake.git branch "master" updated.

Commits to the Asterisk SCF project code repositories asterisk-scf-commits at lists.digium.com
Mon May 9 17:52:28 CDT 2011


branch "master" has been updated
       via  3b96c49972b8f8384c399183a6f5f1e004112dfb (commit)
      from  c4c4b18e8ed2fa8747d0ee8bacdc5122f04d3165 (commit)

Summary of changes:
 AsteriskSCF.cmake |   37 ++++++++++++++++++++-----------------
 1 files changed, 20 insertions(+), 17 deletions(-)


- Log -----------------------------------------------------------------
commit 3b96c49972b8f8384c399183a6f5f1e004112dfb
Author: Kevin P. Fleming <kpfleming at digium.com>
Date:   Mon May 9 17:51:47 2011 -0500

    When computing paths to be included in PATH for tests to be able to run,
    account for the 'Debug' and 'Release' subdirectories created when a build
    is made using Visual Studio project files.

diff --git a/AsteriskSCF.cmake b/AsteriskSCF.cmake
index edd9277..dba221f 100644
--- a/AsteriskSCF.cmake
+++ b/AsteriskSCF.cmake
@@ -134,22 +134,25 @@ if(WIN32 AND ${CMAKE_BUILD_TYPE} STREQUAL profile)
 endif()
 
 if(WIN32)
+  if(MSVC_IDE)
     # The <config>.in files and any other script that reference binary 
-    # directories need to account for the /Debug and /Release subdirectories for Windows.
-    set(binsubdir "/${CMAKE_BUILD_TYPE}" CACHE INTERNAL "Subfolder for binary output. Only set on Windows.")
-
-    #
-    # On 64 bit builds on Windows (Windows x64), projects that include
-    # pjproject header files need to define the architecture to allow
-    # the appropriate definitions to be compiled in. Note that this may
-    # not be entirely accurate as its not clear whether CMake defines this
-    # as 1 when IA64 is the target. Seeing as IA64 is not common and our
-    # projects don't have support for it anyway, we'll go with the
-    # assumption that this is an x64 type platform.
-    #
-    if(${CMAKE_CL_64})
-        add_definitions(-D__amd64)	
-    endif()
+    # directories need to account for the /Debug and /Release subdirectories for Visual Studio
+    # project file based builds.
+    set(BINARY_SUBDIR "/${CMAKE_BUILD_TYPE}" CACHE INTERNAL "Subfolder for binary output. Only set for Visual Studio project file based builds.")
+  endif()
+
+  #
+  # On 64 bit builds on Windows (Windows x64), projects that include
+  # pjproject header files need to define the architecture to allow
+  # the appropriate definitions to be compiled in. Note that this may
+  # not be entirely accurate as its not clear whether CMake defines this
+  # as 1 when IA64 is the target. Seeing as IA64 is not common and our
+  # projects don't have support for it anyway, we'll go with the
+  # assumption that this is an x64 type platform.
+  #
+  if(${CMAKE_CL_64})
+    add_definitions(-D__amd64)	
+  endif()
 endif()
 
 if(UNIX)
@@ -207,7 +210,7 @@ macro(compute_test_paths)
   endforeach()
 
   # Add the project's binary directories for tests and components
-  file(TO_NATIVE_PATH "${PROJECT_BINARY_DIR}/bin" foo)
+  file(TO_NATIVE_PATH "${PROJECT_BINARY_DIR}/bin${BINARY_SUBDIR}" foo)
   list(APPEND test_path_dirs "${foo}")
 
   # Add the Ice directory that contains executables
@@ -216,7 +219,7 @@ macro(compute_test_paths)
 
   # On Windows, we also need some additional directories
   if(WIN32) 
-    file(TO_NATIVE_PATH "${PROJECT_BINARY_DIR}/lib" foo)
+    file(TO_NATIVE_PATH "${PROJECT_BINARY_DIR}/lib${BINARY_SUBDIR}" foo)
     list(APPEND test_path_dirs "${foo}")
     foreach(test_path_dir ${Boost_LIBRARY_DIRS})
       file(TO_NATIVE_PATH "${test_path_dir}" foo)

-----------------------------------------------------------------------


-- 
asterisk-scf/release/cmake.git



More information about the asterisk-scf-commits mailing list